@@ -1,4 +1,4 @@
-from .query import get_filtration
+from .query import get_filtration, set_default_filtration_class
 from .filtration import FiltrationData, ParsingData
 from .table import DataTable
 from .operations import FiltrationOperator
@@ -6,6 +6,8 @@ from .schemas import Filterable, Filter
 
 __all__ = [
     "get_filtration",
+    "set_default_filtration_class",
+    "ParsingData",
     "DataTable",
     "FiltrationData",
     "FiltrationOperator",
